import QtQuick 2.9
import QtQuick.Controls 2.2
import QtQuick.Window 2.2
import b2open.qt 1.0

Window {
    id: root

    visible: true
    width: 640
    height: 480

    property color corFundo: "#242424"
    property color corLaranja: "#f37906"

    property string horaAgora:    "00"
    property string minutoAgora:  "00"
    property string segundoAgora: "00"
    property int tamanhoBorda: 4


    function acertarHora() {
        var date = new Date;
        root.horaAgora = date.getHours();
        root.minutoAgora = date.getMinutes();
        root.segundoAgora = date.getUTCSeconds();

        if (root.horaAgora < 10)    { root.horaAgora    = "0" + root.horaAgora;    }
        if (root.minutoAgora < 10)  { root.minutoAgora  = "0" + root.minutoAgora;  }
        if (root.segundoAgora < 10) { root.segundoAgora = "0" + root.segundoAgora; }
    }


    Component.onCompleted: {
        if (!task.detectTouchScreen()) {
            mensagemErro.text = "Falha no TouchScreen";
            popup.visible = true;
        }
        if (!task.detectIpeBoard()) {
            mensagemErro.text = "IPE Board\nnão detectada!";
            popup.visible = true;
        }
    }

    FontLoader { id: oxygenFont;   source: "RES/FONTS/OxygenMono-Regular.ttf" }
    FontLoader { id: openSansFont; source: "RES/FONTS/OpenSans-Regular.ttf"   }
    FontLoader { id: ralewayFont;  source: "RES/FONTS/Raleway-Thin.ttf"       }

    Timer {
        interval: 1000; running: true; repeat: true;
        onTriggered: {
            root.acertarHora()
        }
    }

    Tasks {
        id: task
    }

    Rectangle {
        id: popup
        width: parent.width
        height: parent.height
        anchors.centerIn: parent
        color: "#55000000"
        visible: false
        z: 99

        Rectangle {
            width: parent.width*0.8
            height: parent.height*0.8
            anchors.centerIn: parent
            color: "red"
            radius: 8

            Text {
                anchors.centerIn: parent
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                font.pointSize: 32
                color: "white"
                id: mensagemErro
            }
        }
    }

    SwipeView {
        id: viewMeteorologia

        currentIndex: 0
        width: parent.width
        height: parent.height*0.725
        focus: true
        z: 95

        Item {

            Meteorologia {
                anchors.fill: parent
                localizacao: "São Carlos"
                tempMax: 29.3
                tempMin: 22.1
                imgMeteorologia: "RES/IMAGES/Day3.svg"
            }

        }

        Item {

            Meteorologia {
                anchors.fill: parent
                localizacao: "Araraquara"
                tempMax: 30.9
                tempMin: 23.3
                imgMeteorologia: "RES/IMAGES/Day1.svg"
            }

        }


        Keys.onReleased: {
            if ((event.key == Qt.Key_Enter) || (event.key == Qt.Key_Return)) {
                console.log("Enter Liberado")
                if (viewMeteorologia.currentIndex === 1) {
                    viewMeteorologia.currentIndex = 0;
                }
                else {
                    viewMeteorologia.currentIndex++
                }
            } else if (event.key == Qt.Key_VolumeUp) {
                console.log("Display Off");
                task.displayOff();

            } else if (event.key == Qt.Key_VolumeDown) {
                console.log("Reduzindo Brilho");
                task.displayBrightness(5);
            } else {
                //console.log("Key:"+event.key)
                //console.log("Enter: "+Qt.Key_Enter)
            }
        }

        Keys.onPressed: {
            if (event.key == Qt.Key_VolumeUp) {
                console.log("Display On");
                task.displayOn();
            } else if (event.key == Qt.Key_VolumeDown) {
                console.log("Aumentando Brilho");
                task.displayBrightness(7);
            }
        }
    }

    Rectangle {
        id: rectFoo
        width: parent.width
        height: parent.height*0.275
        anchors.top: viewMeteorologia.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        color: root.corLaranja
        border.width: root.tamanhoBorda
        border.color: root.corFundo

        Text {
            id: txtHora
            anchors.centerIn: parent
            font {
                family: openSansFont.name;
                pixelSize: parent.height*0.65
                weight: Font.ExtraBold
            }
            style: Text.Sunken
            color: "#CCFFFFFF"
            text: root.horaAgora + ":" + root.minutoAgora + ":" + root.segundoAgora
        }
    }

}
