import QtQuick 2.9
import QtQuick.Controls 2.3
import b2open.qt 1.0


ApplicationWindow {
    id: root

    visible: true
    visibility: "Maximized"
    width: 640
    height: 480

    property int acelerometroX: 0
    property int acelerometroY: 0
    property int acelerometroZ: 0

    property color colorCaixa: "#88000000"
    property color colorText: "white"

    Acelerometro {
        id: acelerometro
        onChangedEixoX: { acelerometroX = acelerometro.eixoX; }
        onChangedEixoY: { acelerometroY = acelerometro.eixoY; }
        onChangedEixoZ: { acelerometroZ = acelerometro.eixoZ; }
    }

    Buzzer { id: buzzer; pwm: Buzzer.PWM_D; period: 100; dutycycle: 100; }

    Led { id: led101; led: Led.Led101; modo: Led.HeartBeat; }
    Led { id: led103; led: Led.Led103; modo: Led.Timer;     }
    Led { id: led133; led: Led.Led133;                      }


    // Imagem de Plano de Fundo
    Image {
        id: bg
        anchors.fill: parent
        asynchronous: true
        //source: "RES/IMAGES/bg-dark-blue-glossy-polygonal-motion.png"
        source: "RES/IMAGES/bg-dark-green.png"
        //source: "RES/IMAGES/bg-new-york-night.png"

        focus: true
        Keys.onReleased: {
            if (event.key == Qt.Key_VolumeUp) {
                console.log("Volume Up")
                root.colorCaixa = "#88FFFFFF"
                root.colorText = Qt.darker("gray");
            } else if (event.key == Qt.Key_VolumeDown) {
                console.log("Volume Down")
                root.colorCaixa = "#88000000";
                root.colorText = "white";
            } else {
                //console.log("Key:"+event.key)
                //console.log("Enter: "+Qt.Key_Enter)
            }

        }
    }

    // Button Power Off
    Rectangle {
        width: 64
        height: 64
        color: Qt.darker("red")
        anchors.top: parent.top
        anchors.right: parent.right
        anchors.margins: 10
        radius: width/2

        Image {
            anchors.centerIn: parent
            source: "RES/IMAGES/power-button.svg"
            width: 48
            height: 48
            sourceSize: Qt.size(width, height)
        }

        MouseArea {
            anchors.fill: parent
            onPressed: {
                parent.scale = 0.95
            }
            onReleased: {
                parent.scale = 1.0
            }
        }
    }

    // Primeiro Retangulo - Leds
    Rectangle {
        id: rect1
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 20
        anchors.right: rect2.left
        anchors.rightMargin: 10
        width: parent.width*0.3
        height: parent.height*0.8
        color: root.colorCaixa
        radius: 4

        // Coluna organizando os Itens Leds
        Column {
            anchors.fill: parent
            spacing: 10

            Text {
                width: parent.width
                height: 50
                horizontalAlignment: Text.AlignHCenter
                font.pointSize: 18
                font.bold: true
                color: root.colorText
                text: qsTr("LEDs")
            }

            // Led1
            Row {
                spacing: 5
                width: parent.width

                Text {
                    width: parent.width/2
                    height: 50
                    verticalAlignment: Text.AlignVCenter
                    font.pointSize: 16
                    color: root.colorText
                    text: qsTr("LED1")
                }

                MySwitch {
                    width: parent.width/2
                    height: 50

                    onStatus: {
                        if (flag) {
                            console.log("[QML] Ligando Led1");
                            led101.ligar = true;
                        }
                        else {
                            console.log("[QML] Desligando Led1")
                            led101.ligar = false;
                        }
                    }
                }
            }

            // Led2
            Row {
                spacing: 5
                width: parent.width

                Text {
                    width: parent.width/2
                    height: 50
                    verticalAlignment: Text.AlignVCenter
                    font.pointSize: 16
                    color: root.colorText
                    text: qsTr("LED2")
                }

                MySwitch {
                    width: parent.width/2
                    height: 50

                    onStatus: {
                        if (flag) {
                            console.log("[QML] Ligando Led2");
                            led103.ligar = true;
                        }
                        else {
                            console.log("[QML] Desligando Led2")
                            led103.ligar = false;
                        }
                    }
                }
            }

            // Led3
            Row {
                spacing: 5
                width: parent.width

                Text {
                    width: parent.width/2
                    height: 50
                    verticalAlignment: Text.AlignVCenter
                    font.pointSize: 16
                    color: root.colorText
                    text: qsTr("LED3")
                }

                MySwitch {
                    width: parent.width/2
                    height: 50

                    onStatus: {
                        if (flag) {
                            console.log("[QML] Ligando Led3");
                            led133.on();
                        }
                        else {
                            console.log("[QML] Desligando Led3")
                            led133.off()
                        }
                    }
                }
            }
        }


    }

    // Segundo Retangulo - Acelerometro
    Rectangle {
        id: rect2
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 20
        anchors.horizontalCenter: parent.horizontalCenter
        width: parent.width*0.3
        height: parent.height*0.8
        color: root.colorCaixa
        radius: 4

        Column {
            anchors.fill: parent
            spacing: 10

            Text {
                width: parent.width
                height: 50
                horizontalAlignment: Text.AlignHCenter
                font.pointSize: 18
                font.bold: true
                color: root.colorText
                text: qsTr("ACELEROMETRO")
            }

            Column {
                spacing: 5
                width: parent.width

                Text {
                    width: parent.width/2
                    height: 50
                    verticalAlignment: Text.AlignVCenter
                    font.pointSize: 16
                    color: root.colorText
                    text: "X: "+root.acelerometroX
                }
                Text {
                    width: parent.width/2
                    height: 50
                    verticalAlignment: Text.AlignVCenter
                    font.pointSize: 16
                    color: root.colorText
                    text: "Y: "+root.acelerometroY
                }
                Text {
                    width: parent.width/2
                    height: 50
                    verticalAlignment: Text.AlignVCenter
                    font.pointSize: 16
                    color: root.colorText
                    text: "Z: "+root.acelerometroZ
                }

            }
        }

    }

    // Terceiro Retangulo - Buzzer
    Rectangle {
        id: rect3
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 20
        anchors.left: rect2.right
        anchors.leftMargin: 10
        width: parent.width*0.3
        height: parent.height*0.8
        color: root.colorCaixa
        radius: 4

        // Coluna organizando os Itens Buzzer
        Column {
            anchors.fill: parent
            spacing: 10

            Text {
                width: parent.width
                height: 50
                horizontalAlignment: Text.AlignHCenter
                font.pointSize: 18
                font.bold: true
                color: root.colorText
                text: qsTr("BUZZER")
            }

            // PWM Periodo
            Text {
                width: parent.width
                height: 50
                verticalAlignment: Text.AlignVCenter
                font.pointSize: 16
                color: root.colorText
                text: qsTr("Periodo   : "+slider_buzzer_period.value+"ms")
            }
            Slider {
                id: slider_buzzer_period
                width: parent.width
                height: 50
                stepSize: 100
                from: 100
                value: 100
                to: 1000

                onValueChanged: {
                    //console.log("Periodo: "+value)
                    buzzer.period = value
                }
            }

            // PWM DutyCycle
            Text {
                width: parent.width
                height: 50
                verticalAlignment: Text.AlignVCenter
                font.pointSize: 16
                color: root.colorText
                text: qsTr("DutyCycle : "+slider_buzzer_ducycycle.value+"ms")
            }
            Slider {
                id: slider_buzzer_ducycycle
                width: parent.width
                height: 50
                stepSize: 100
                from: 100
                value: 100
                to: 1000

                onValueChanged: {
                    //console.log("DutyCycle: "+value)
                    buzzer.dutycycle = value;
                }
            }

            // Habilitar PWM
            Rectangle {
                width: parent.width-50
                anchors.horizontalCenter: parent.horizontalCenter
                height: 50
                color: "gold"

                Text {
                    id: txtEnablePwmBuzzer
                    anchors.centerIn: parent
                    font.pointSize: 26
                    color: "#383838"
                    text: qsTr("LIGAR")
                }
                MouseArea {
                    anchors.fill: parent
                    onPressed: { parent.scale = 0.95; }
                    onReleased: {
                        parent.scale = 1.0;
                        if (txtEnablePwmBuzzer.text == "LIGAR") {

                            txtEnablePwmBuzzer.text = "DESLIGAR";
                            buzzer.run = true;
                        } else {
                            txtEnablePwmBuzzer.text = "LIGAR";
                            buzzer.run = false;
                        }
                    }
                }
            }

        }
    }


}
